@@ -6,9 +6,9 @@ Type annotations for dlm service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_dlm.type_defs import ResponseMetadataTypeDef
+    from mypy_boto3_dlm.type_defs import RetentionArchiveTierTypeDef
 
-    data: ResponseMetadataTypeDef = {...}
+    data: RetentionArchiveTierTypeDef = {...}
     ```
 """
 import sys
@@ -36,6 +36,7 @@ else:
 
 
 __all__ = (
+    "RetentionArchiveTierTypeDef",
     "ResponseMetadataTypeDef",
     "CreateRuleTypeDef",
     "CrossRegionCopyRetainRuleTypeDef",
@@ -49,18 +50,20 @@ __all__ = (
     "LifecyclePolicySummaryTypeDef",
     "GetLifecyclePolicyRequestRequestTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
-    "ParametersTypeDef",
     "TagTypeDef",
     "RetainRuleTypeDef",
     "ShareRuleTypeDef",
     "TagResourceRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
+    "ArchiveRetainRuleTypeDef",
     "CreateLifecyclePolicyResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "CrossRegionCopyActionTypeDef",
     "CrossRegionCopyRuleTypeDef",
     "EventSourceTypeDef",
     "GetLifecyclePoliciesResponseTypeDef",
+    "ParametersTypeDef",
+    "ArchiveRuleTypeDef",
     "ActionTypeDef",
     "ScheduleTypeDef",
     "PolicyDetailsTypeDef",
@@ -70,6 +73,16 @@ __all__ = (
     "GetLifecyclePolicyResponseTypeDef",
 )
 
+RetentionArchiveTierTypeDef = TypedDict(
+    "RetentionArchiveTierTypeDef",
+    {
+        "Count": int,
+        "Interval": int,
+        "IntervalUnit": RetentionIntervalUnitValuesType,
+    },
+    total=False,
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -217,15 +230,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ParametersTypeDef = TypedDict(
-    "ParametersTypeDef",
-    {
-        "ExcludeBootVolume": bool,
-        "NoReboot": bool,
-    },
-    total=False,
-)
-
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -280,6 +284,13 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+ArchiveRetainRuleTypeDef = TypedDict(
+    "ArchiveRetainRuleTypeDef",
+    {
+        "RetentionArchiveTier": RetentionArchiveTierTypeDef,
+    },
+)
+
 CreateLifecyclePolicyResponseTypeDef = TypedDict(
     "CreateLifecyclePolicyResponseTypeDef",
     {
@@ -371,6 +382,23 @@ GetLifecyclePoliciesResponseTypeDef = TypedDict(
     },
 )
 
+ParametersTypeDef = TypedDict(
+    "ParametersTypeDef",
+    {
+        "ExcludeBootVolume": bool,
+        "NoReboot": bool,
+        "ExcludeDataVolumeTags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+ArchiveRuleTypeDef = TypedDict(
+    "ArchiveRuleTypeDef",
+    {
+        "RetainRule": ArchiveRetainRuleTypeDef,
+    },
+)
+
 ActionTypeDef = TypedDict(
     "ActionTypeDef",
     {
@@ -392,6 +420,7 @@ ScheduleTypeDef = TypedDict(
         "CrossRegionCopyRules": Sequence[CrossRegionCopyRuleTypeDef],
         "ShareRules": Sequence[ShareRuleTypeDef],
         "DeprecateRule": DeprecateRuleTypeDef,
+        "ArchiveRule": ArchiveRuleTypeDef,
     },
     total=False,
 )
